@@ -1,5 +1,5 @@
-from emannotationschemas.schemas.base import ReferenceAnnotation
 import marshmallow as mm
+from emannotationschemas.schemas.base import ReferenceAnnotation
 from marshmallow.validate import OneOf
 
 
@@ -7,12 +7,12 @@ class BoutonShape(ReferenceAnnotation):
 
     target_id = mm.fields.Int(
         required=True,
-        description='annotation this references',
-        reference_type='synapse')
+        description="annotation this references",
+        reference_type="synapse",
+    )
 
     shape = mm.fields.Str(
         required=True,
         validate=OneOf(["pancake", "basmati", "potato"]),
-        description="first example of description of a bouton shape")
-
-
+        description="first example of description of a bouton shape",
+    )
