@@ -1,9 +1,9 @@
-from marshmallow import fields, validate
 from emannotationschemas.schemas.base import (
-    BoundSpatialPoint,
     AnnotationSchema,
+    BoundSpatialPoint,
     NumericField,
 )
+from marshmallow import fields, validate
 
 proofread_choices = ["non", "clean", "extended"]
 options_text = "Options are: 'non' to indicate no comprehensive proofreading, 'clean' to indicate comprehensive removal of false merges, and 'extended' to mean comprehensive extension of neurite tips"
@@ -15,7 +15,7 @@ class PointWithValid(AnnotationSchema):
         required=True,
         description="Core location on proofread object",
     )
-    valid_root_id = NumericField(
+    valid_id = NumericField(
         required=True,
         description="Root id of the object when proofread status was assigned. If the pt_root_id of the cell differs, the proofreading status may not apply.",
     )
