@@ -1,32 +1,30 @@
-from emannotationschemas.schemas.proofreading import (
-    ProofreadStatus,
-    CompartmentProofreadStatus,
-)
 import pytest
+from emannotationschemas.schemas.proofreading import (
+    CompartmentProofreadStatus, ProofreadStatus)
 from marshmallow import ValidationError
 
 good_base_data = {
     "pt": {"position": [1, 2, 3]},
-    "valid_root_id": 1234567,
+    "valid_id": 1234567,
     "status": "clean",
 }
 
 bad_base_data = {
     "pt": {"position": [1, 2, 3]},
-    "valid_root_id": 1234567,
+    "valid_id": 1234567,
     "status": "some_nonsense",
 }
 
 good_comp_data = {
     "pt": {"position": [1, 2, 3]},
-    "valid_root_id": 1234567,
+    "valid_id": 1234567,
     "status_axon": "clean",
     "status_dendrite": "extended",
 }
 
 bad_comp_data = {
     "pt": {"position": [1, 2, 3]},
-    "valid_root_id": 1234567,
+    "valid_id": 1234567,
     "status_dendrite": "clean",
 }
 
@@ -51,4 +49,4 @@ def test_compartment_proofreading_validation():
     assert result["status_dendrite"] == "extended"
 
     with pytest.raises(ValidationError):
-        schema.load(bad_comp_data)
\ No newline at end of file
+        schema.load(bad_comp_data)
